@@ -13,6 +13,8 @@ class CreateBulkModelMixin(object):
     Create model instances in bulk.
     """
 
+    send_create_signals = True
+
     @action(detail=False, methods=["POST"], url_path="bulk_create")
     def create_bulk(self, request, *args, **kwargs):
         serializer = self.get_serializer(data=request.data, many=True)
@@ -26,8 +28,9 @@ class CreateBulkModelMixin(object):
     def perform_create_bulk(self, serializer):
         instances = serializer.save()
 
-        for instance in instances:
-            post_save.send(instance.__class__, instance=instance, created=True)
+        if self.send_create_signals:
+            for instance in instances:
+                post_save.send(instance.__class__, instance=instance, created=True)
 
         return instances
 
@@ -43,6 +46,8 @@ class UpdateBulkModelMixin(object):
     Update model instances in bulk.
     """
 
+    send_update_signals = True
+
     @action(detail=False, methods=["PATCH"], url_path="bulk_update")
     def update_bulk(self, request, *args, **kwargs):
         instances = self.get_update_instances(request.data)
@@ -59,8 +64,9 @@ class UpdateBulkModelMixin(object):
     def perform_update_bulk(self, serializer):
         instances = serializer.save()
 
-        for instance in instances:
-            post_save.send(instance.__class__, instance=instance, created=False)
+        if self.send_update_signals:
+            for instance in instances:
+                post_save.send(instance.__class__, instance=instance, created=False)
 
         return instances
 
